<?php
/**
 * @package WordPress
 * @subpackage multi-color
 */
error_reporting (E_ALL ^ E_NOTICE);

/******************************************************************************************************************************************/
/** Theme Options **/
/******************************************************************************************************************************************/
require_once(TEMPLATEPATH . '/admin/admin_options.php');

/******************************************************************************************************************************************/
/** Retrieving Options **/
/******************************************************************************************************************************************/
$options = get_option('mc_options');

/******************************************************************************************************************************************/
/** Function to initialize options incase they are not set **/
/******************************************************************************************************************************************/
function initialize_options() {
    $options = get_option('mc_options');
    if(!is_array($options) or trim($options['mc_color_scheme']) == "") {
    	$options['mc_color_scheme'] = 'light';
        $options['mc_blog_style'] = 'traditional';        
        $options['mc_content_width'] = 900;
        $options['mc_show_sidebar'] = true;
        $options['mc_sidebar_width'] = 240;
        $options['mc_header_height'] = 150;
        $options['mc_thumbnail_size'] = 165;
        $options['mc_tab_count'] = 0;
        $options['mc_tab1_title'] = __('Tab 1','multi-color');
        $options['mc_tab2_title'] = __('Tab 2','multi-color');
        $options['mc_tab3_title'] = __('Tab 3','multi-color');
        $options['mc_add_rss'] = true;
        $options['mc_add_adsense'] = false;
        $options['mc_add_twitter'] = false;
        $options['mc_add_flickr'] = false;
        $options['mc_add_breadcrumbs'] = false;
        $options['mc_show_category'] = true;
        $options['mc_show_tags'] = true;
        $options['mc_excerpt_traditional'] = false;
        $options['mc_show_page_meta'] = false;
        $options['mc_show_bookmark_links'] = true;
    }
    return $options;
}

/******************************************************************************************************************************************/
/** Defining constants from the option values **/
/******************************************************************************************************************************************/
if(!is_array($options) or trim($options['mc_color_scheme']) == "") {
	$options = initialize_options();
}

define("COLOR_SCHEME",$options['mc_color_scheme']);
define("BLOG_STYLE",$options['mc_blog_style']);
define("CONTENT_WIDTH",$options['mc_content_width']);
define("SHOW_SIDEBAR",$options['mc_show_sidebar']);
define("SIDEBAR_WIDTH",$options['mc_sidebar_width']);
define("HEADER_HEIGHT",$options['mc_header_height']);
define("MAG_THUMB",$options['mc_thumbnail_size']);
define("TAB_COUNT",$options['mc_tab_count']);
define("TAB1_TITLE",$options['mc_tab1_title']);
define("TAB2_TITLE",$options['mc_tab2_title']);
define("TAB3_TITLE",$options['mc_tab3_title']);
define("ADD_RSS",$options['mc_add_rss']);
define("ADD_ADSENSE",$options['mc_add_adsense']);
define("ADD_TWITTER",$options['mc_add_twitter']);
define("ADD_FLICKR",$options['mc_add_flickr']);
define("SHOW_BREADCRUMBS",$options['mc_add_breadcrumbs']);
define("SHOW_CATEGORY",$options['mc_show_category']);
define("SHOW_TAGS",$options['mc_show_tags']);
define("SHOW_TRAD_EXCERPT",$options['mc_excerpt_traditional']);
define("SHOW_PAGE_META",$options['mc_show_page_meta']);
define("SHOW_BOOKMARKS",$options['mc_show_bookmark_links']);
define( 'HEADER_TEXTCOLOR', apply_filters('multi-color_header_textcolor', 'ffffff') );
define( 'HEADER_IMAGE', apply_filters('multi-color_header_image', '%s/images/headers/default.png') );
define( 'HEADER_IMAGE_WIDTH', apply_filters('multi-color_header_image_width', $options['mc_content_width']) );
define( 'HEADER_IMAGE_HEIGHT', apply_filters('multi-color_header_image_height', $options['mc_header_height']) );
define( 'NO_HEADER_TEXT', apply_filters('multi-color_header_text', false) );

/******************************************************************************************************************************************/
/** Function to calculate container & sidebar width **/
/******************************************************************************************************************************************/
function calculate_layout_width() {
    $widthsarr = array('containerwidth' => '', 'sidebarwidth' => '');
    if(SHOW_SIDEBAR) {
        $sidebarwidth = SIDEBAR_WIDTH;
        $containerwidth = CONTENT_WIDTH - $sidebarwidth - 50;
    } else {
        $sidebarwidth = 0;
        $containerwidth = CONTENT_WIDTH - $sidebarwidth;
    }
    $widthsarr['containerwidth'] = $containerwidth;
    $widthsarr['sidebarwidth'] = $sidebarwidth;
    return $widthsarr;
}

/******************************************************************************************************************************************/
/** Registering sidebars, tabbed content area and footer-sidebars **/
/******************************************************************************************************************************************/
register_sidebar( array(
    'name' => __( 'Primary Widget Area', 'multi-color' ),
    'id' => 'primary-widget-area',
    'description' => __( 'The primary widget area', 'multi-color' ),
    'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
    'after_widget' => '</li>',
    'before_title' => '<h3 class="widget-title">',
    'after_title' => '</h3>',
) );

if(TAB_COUNT >= 1 and TAB_COUNT <= 3) {
    register_sidebar( array(
        'name' => __( 'Tabbed Content Area 1', 'multi-color' ),
        'id' => 'tabbed-content-area-1',
        'description' => __( 'The tabbed widget area 1', 'multi-color' ),
        'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ) );
}
if(TAB_COUNT >= 2 and TAB_COUNT <= 3) {
register_sidebar( array(
    'name' => __( 'Tabbed Content Area 2', 'multi-color' ),
    'id' => 'tabbed-content-area-2',
    'description' => __( 'The tabbed widget area 2', 'multi-color' ),
    'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
    'after_widget' => '</li>',
    'before_title' => '<h3 class="widget-title">',
    'after_title' => '</h3>',
) );
}

if(TAB_COUNT == 3) {
register_sidebar( array(
    'name' => __( 'Tabbed Content Area 3', 'multi-color' ),
    'id' => 'tabbed-content-area-3',
    'description' => __( 'The tabbed widget area 3', 'multi-color' ),
    'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
    'after_widget' => '</li>',
    'before_title' => '<h3 class="widget-title">',
    'after_title' => '</h3>',
) );
}

register_sidebar( array(
    'name' => __( 'Footer Widget Area 1', 'multi-color' ),
    'id' => 'footer-widget-area-1',
    'description' => __( 'Footer widget area 1', 'multi-color' ),
    'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
    'after_widget' => '</li>',
    'before_title' => '<h3 class="widget-title">',
    'after_title' => '</h3>',
) );

register_sidebar( array(
    'name' => __( 'Footer Widget Area 2', 'multi-color' ),
    'id' => 'footer-widget-area-2',
    'description' => __( 'Footer widget area 2', 'multi-color' ),
    'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
    'after_widget' => '</li>',
    'before_title' => '<h3 class="widget-title">',
    'after_title' => '</h3>',
) );

register_sidebar( array(
    'name' => __( 'Footer Widget Area 3', 'multi-color' ),
    'id' => 'footer-widget-area-3',
    'description' => __( 'Footer widget area 3', 'multi-color' ),
    'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
    'after_widget' => '</li>',
    'before_title' => '<h3 class="widget-title">',
    'after_title' => '</h3>',
) );


/******************************************************************************************************************************************/
/** Configuring custom widgets **/
/******************************************************************************************************************************************/

if(ADD_ADSENSE) {    
    register_widget('AdsenseWidget');
}

if(ADD_RSS) {
    register_widget('RssWidget');
}

if(ADD_TWITTER) {
    register_widget('TwitterWidget');
    add_action('wp_footer','add_twitter_config');
}

if(ADD_FLICKR) {
    register_widget('FlickrWidget');
}

class AdsenseWidget extends WP_Widget {
    function AdsenseWidget() {
        $widgetops = array('classname' => 'widget_adsense', 'description' => __('Widget to display your adsense code','multi-color'));
        $this->WP_Widget('adsense',__('Adsense Code','multi-color'),$widgetops);
    }
    
    function widget($args,$instance) {
        extract($args, EXTR_SKIP);
        echo $before_widget;
        $title = empty($instance['title']) ? ' ' : apply_filters('widget_title', $instance['title']);
        if ( !empty( $title ) ) { echo $before_title . $title . $after_title; };
        echo '<div class="adsense">'."\n";
        echo $instance['code'];
        echo '</div>'."\n";
        echo $after_widget;
    }
    
    function update($new_instance,$old_instance) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['code'] = trim($new_instance['code']);
        return $instance;
    }
    
    function form($instance) {
        $instance = wp_parse_args( (array) $instance, array( 'title' => '', 'code' => '' ) );
        $title = strip_tags($instance['title']);
        $code = trim($instance['code']);
    ?>
    <p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:','multi-color'); ?> <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo attribute_escape($title); ?>" /></label></p>
    <p><label for="<?php echo $this->get_field_id('code'); ?>"><?php _e('Code:','multi-color'); ?> <textarea class="widefat" id="<?php echo $this->get_field_id('code'); ?>" name="<?php echo $this->get_field_name('code'); ?>"><?php echo attribute_escape($code); ?></textarea></label></p>
    <?php
    }
}

class RssWidget extends WP_Widget {
    function RssWidget() {
        $widgetops = array('classname' => 'widget_rss', 'description' => __('Widget to display rss links for blog','multi-color'));
        $this->WP_Widget('rss_links',__('Subscribe to RSS','multi-color'),$widgetops);
    }
    
    function widget($args,$instance) {
        extract($args, EXTR_SKIP);
        echo $before_widget;
        $title = empty($instance['title']) ? ' ' : apply_filters('widget_title', $instance['title']);
        if ( !empty( $title ) ) { echo $before_title . $title . $after_title; };
        echo '<table class="rss_tab">'."\n";
        echo '<tr><td style="width:48px;"><img src="'.get_template_directory_uri().'/images/rss_'.COLOR_SCHEME.'.png" /></td>'."\n";
        echo '<td style="font-size:1em;font-weight:bold;padding-left:10px;"><p><a href="'.get_bloginfo('rss2_url').'">'.__('Subscribe to blog','multi-color').'</a></p> <p style="margin-top:5px;"><a href="'.get_bloginfo('comments_rss2_url').'">'.__('Subscribe to comments','multi-color').'</a></p></td>';
        echo '</table>'."\n";
        echo $after_widget;
    }
    
    function update($new_instance,$old_instance) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        return $instance;
    }
    
    function form($instance) {
        $instance = wp_parse_args( (array) $instance, array( 'title' => '') );
        $title = strip_tags($instance['title']);
    ?>
    <p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:','multi-color'); ?> <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo attribute_escape($title); ?>" /></label></p>
    <?php
    }
}

class TwitterWidget extends WP_Widget {
    function TwitterWidget() {
        $widgetops = array('classname' => 'widget_twitter', 'description' => __('Widget to display your twitter feeds','multi-color'));
        $this->WP_Widget('twitter',__('Twitter','multi-color'),$widgetops);
    }
    
    function widget($args,$instance) {
        extract($args, EXTR_SKIP);
        echo $before_widget;
        $title = empty($instance['title']) ? ' ' : apply_filters('widget_title', $instance['title']);
        if ( !empty( $title ) ) { echo $before_title . $title . $after_title; };
        echo '<ul id="twitter_update_list"><li>'.__('Tweetie is sleeping','multi-color').'</li></ul>'."\n";
        echo $after_widget;        
    }    
    
    function update($new_instance,$old_instance) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['username'] = strip_tags($new_instance['username']);
        $instance['count'] = strip_tags($new_instance['count']);
        update_option('mctwitter_username',$instance['username']);
        update_option('mctwitter_count',$instance['count']);
        return $instance;
    }    
    
    function form($instance) {
        $instance = wp_parse_args( (array) $instance, array( 'title' => '', 'username' => '', 'count' => '' ) );
        $title = strip_tags($instance['title']);
        $username = strip_tags($instance['username']);
        $count = strip_tags($instance['count']);
    ?>
    <p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:','multi-color'); ?> <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo attribute_escape($title); ?>" /></label></p>
    <p><label for="<?php echo $this->get_field_id('username'); ?>"><?php _e('Username:','multi-color'); ?> <input class="widefat" id="<?php echo $this->get_field_id('username'); ?>" name="<?php echo $this->get_field_name('username'); ?>" type="text" value="<?php echo attribute_escape($username); ?>" /></label></p>    
    <p><label for="<?php echo $this->get_field_id('count'); ?>"><?php _e('Count:','multi-color'); ?> <input class="widefat" id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>" type="text" value="<?php echo attribute_escape($count); ?>" /></label></p>
    <?php
    }
}

function add_twitter_config() {
    echo '<script type="text/javascript" src="http://twitter.com/javascripts/blogger.js"></script>'."\n";
    echo '<script type="text/javascript" src="http://twitter.com/statuses/user_timeline/'.get_option('mctwitter_username').'.json?callback=twitterCallback2&amp;count='.get_option('mctwitter_count').'"></script>'."\n";
}

class FlickrWidget extends WP_Widget {
    function FlickrWidget() {
        $widgetops = array('classname' => 'widget_flickr', 'description' => __('Widget to display your flickr photostream','multi-color'));
        $this->WP_Widget('flickr',__('Flickr','multi-color'),$widgetops);
    }
    
    function widget($args,$instance) {
        extract($args, EXTR_SKIP);
        echo $before_widget;
        $title = empty($instance['title']) ? ' ' : apply_filters('widget_title', $instance['title']);
        if ( !empty( $title ) ) { echo $before_title . $title . $after_title; };
        echo '<div id="flickr_content"><script type="text/javascript" src="http://www.flickr.com/badge_code_v2.gne?count='.$instance['count'].'&display=latest&size=s&layout=h&source=user&user='.$instance['username'].'"></script></div>'."\n"; //49460732%40N02
        echo $after_widget;        
    }    
    
    function update($new_instance,$old_instance) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['username'] = strip_tags($new_instance['username']);
        $instance['count'] = strip_tags($new_instance['count']);
        return $instance;
    }    
    
    function form($instance) {
        $instance = wp_parse_args( (array) $instance, array( 'title' => '', 'username' => '', 'count' => '' ) );
        $title = strip_tags($instance['title']);
        $username = strip_tags($instance['username']);
        $count = strip_tags($instance['count']);
    ?>
    <p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:','multi-color'); ?> <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo attribute_escape($title); ?>" /></label></p>
    <p><label for="<?php echo $this->get_field_id('username'); ?>"><?php _e('User Id:','multi-color'); ?> <input class="widefat" id="<?php echo $this->get_field_id('username'); ?>" name="<?php echo $this->get_field_name('username'); ?>" type="text" value="<?php echo attribute_escape($username); ?>" /></label></p>    
    <p><label for="<?php echo $this->get_field_id('count'); ?>"><?php _e('Count:','multi-color'); ?> <input class="widefat" id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>" type="text" value="<?php echo attribute_escape($count); ?>" /></label></p>
    <?php
    }
}

/******************************************************************************************************************************************/
/** Function to display breadcrumbs **/
/******************************************************************************************************************************************/

function the_breadcrumb() {
    global $post;
    if (!is_home()) {
        echo '<div class="breadcrumbs"><a href="';
        echo get_home_url();
        echo '">';
        _e('Home');
        echo "</a> &raquo; ";
        if (is_category() || is_single()) {
            single_cat_title();
            if (is_single()) {
                _e(get_single_category($post->ID));
                echo " &raquo; ";
                the_title();
            }
        } elseif (is_tag()) {
            single_tag_title();
        } elseif (is_page()) {
            echo the_title();
        } elseif (is_day()) {
            echo __('Archive for ','multi-color'); the_time('F jS, Y');
        } elseif (is_month()) {
            echo __('Archive for ','multi-color'); the_time('F, Y');
        } elseif (is_year()) {
            echo __('Archive for ','multi-color'); the_time('Y');
        } elseif (is_author()) {
            echo __('Author Archive','multi-color');
        } elseif (isset($_GET['paged']) && !empty($_GET['paged'])) {
            echo __('Blog Archives','multi-color');
        } elseif (is_search()) {
            echo __('Search Results for ','multi-color').get_search_query();
        }
        echo '</div>'."\n";
    }
}

/******************************************************************************************************************************************/
/** Function to create single category link **/
/******************************************************************************************************************************************/
function get_single_category($postid) {
    $category = get_the_category($postid);
    return '<a href="'.get_category_link($category[0]->cat_ID).'">'.$category[0]->cat_name.'</a>';
}

/******************************************************************************************************************************************/
/** Function to create social bookmarks array **/
/******************************************************************************************************************************************/
function social_bookmarks() {
    define("SHARETITLE",get_the_title());
    define("SHAREPERMALINK",get_permalink());
    define("SHAREEXCERPT",htmlspecialchars(get_the_excerpt()));
    define("SHAREBLOGNAME",get_bloginfo('name'));
    $social_bookmarks = array(
        array('name' => __( 'facebook','multi-color' ), 'icon' => 'facebook.png', 'bookmarkurl' => 'http://www.facebook.com/share.php?u='.SHAREPERMALINK.'&amp;t='.SHARETITLE),
        array('name' => __( 'twitter','multi-color' ), 'icon' => 'twitter.png', 'bookmarkurl' => 'http://twitter.com/home?status='.SHARETITLE.'%20-%20'.SHAREPERMALINK),
        array('name' => __( 'delicious','multi-color' ), 'icon' => 'delicious.png', 'bookmarkurl' => 'http://delicious.com/post?url='.SHAREPERMALINK.'&amp;title='.SHARETITLE.'&amp;notes='.SHAREEXCERPT),
        array('name' => __( 'digg','multi-color' ), 'icon' => 'digg.png', 'bookmarkurl' => 'http://digg.com/submit?phase=2&amp;url='.SHAREPERMALINK.'&amp;title='.SHARETITLE.'&amp;bodytext='.SHAREEXCERPT),
        array('name' => __( 'google','multi-color' ), 'icon' => 'google.png', 'bookmarkurl' => 'http://www.google.com/bookmarks/mark?op=edit&amp;bkmk='.SHAREPERMALINK.'&amp;title='.SHARETITLE.'&amp;annotation='.SHAREEXCERPT),
        array('name' => __( 'reddit','multi-color' ), 'icon' => 'reddit.png', 'bookmarkurl' => 'http://reddit.com/submit?url='.SHAREPERMALINK.'&amp;title='.SHARETITLE),
        array('name' => __( 'stumbleupon','multi-color' ), 'icon' => 'stumbleupon.png', 'bookmarkurl' => 'http://www.stumbleupon.com/submit?url='.SHAREPERMALINK.'&amp;title='.SHARETITLE),
        array('name' => __( 'technorati','multi-color' ), 'icon' => 'technorati.png', 'bookmarkurl' => 'http://technorati.com/faves?add='.SHAREPERMALINK)
    );
    $bookmarklist = '<span class="bookmarktitle">'.__('Share this','multi-color').'</span>';
    foreach($social_bookmarks as $bookmark) {
       $bookmarklist .= '<a class="social_bookmark" title="'.__('Share this article on ','multi-color').ucwords($bookmark['name']).'" href="'.$bookmark['bookmarkurl'].'"><img src="'.get_template_directory_uri().'/images/social/'.$bookmark['icon'].'" /></a>'."\n"; 
    }
    return $bookmarklist;
}

/******************************************************************************************************************************************/
/** Configure Post Thumbnails **/
/******************************************************************************************************************************************/
add_theme_support( 'post-thumbnails' );
set_post_thumbnail_size( MAG_THUMB, MAG_THUMB );
add_image_size('featured-image',MAG_THUMB,MAG_THUMB);

/******************************************************************************************************************************************/
/** Configure automatic feed links **/
/******************************************************************************************************************************************/
add_theme_support( 'automatic-feed-links' );

/******************************************************************************************************************************************/
/** Configure Custom background **/
/******************************************************************************************************************************************/
if(function_exists('add_custom_background')) {
add_custom_background('set_theme_background');
add_theme_support( 'custom-background' );

function set_theme_background() {
        $bgimage = get_background_image();
        $bgcolor = get_background_color();
        $imagedir = get_template_directory_uri();
        echo '<style type="text/css" media="all">'."\n";        
        if(!empty($bgimage)) {
                $background_styles = 'background-image: url(\'' . get_theme_mod('background_image', '') . '\');'
                . ' background-repeat: ' . get_theme_mod('background_repeat', 'repeat') . ';'
                . ' background-position: top ' . get_theme_mod('background_position_x', 'left') .  ';' . 'background-attachment: '. get_theme_mod('background_attachment', 'scroll');
                echo 'body { '.$background_styles.'); } '."\n";
        } 
        if(!empty($bgcolor)) {
                echo 'body { background-color: #'.$bgcolor.'; } '."\n";
        }
        if(empty($bgimage) && !empty($bgcolor)) {
            echo 'body { background-image: url('.$imagedir.'/images/bg.png); background-repeat: repeat; } '."\n";
        }
        if(empty($bgimage) && empty($bgcolor)) {
            echo 'body { background: #777 url('.$imagedir.'/images/bg.png); } '."\n";
        }
        echo '</style>';
}
}

/******************************************************************************************************************************************/
/** Configure theme for multiple languages **/
/******************************************************************************************************************************************/
load_theme_textdomain( 'multi-color', TEMPLATEPATH . '/languages' );
$locale = get_locale();
$locale_file = TEMPLATEPATH . "/languages/$locale.php";
if ( is_readable( $locale_file ) )
    require_once( $locale_file );

/******************************************************************************************************************************************/
/** Configure Custom header image **/
/******************************************************************************************************************************************/
add_custom_image_header( '', 'mc_admin_header_style' );
function mc_admin_header_style() {
?>
<style type="text/css">
    #headimg {width:<?php echo HEADER_IMAGE_WIDTH; ?>px;height:<?php echo HEADER_IMAGE_HEIGHT; ?>px;}
    #headimg #name {font-family:Century Gothic;text-decoration:none;text-shadow:#000 1px 1px;vertical-align:middle;font-size:1.5em;margin-top:20px;margin-left:10px;display:block;}
    #headimg #name a {text-decoration:none;}
    #headimg #desc {font-family:Arial;text-shadow:#000 1px 1px;vertical-align:middle;font-size:0.875em;margin-left:10px;}
</style>
<?php
}

/******************************************************************************************************************************************/
/** Configure Custom Menu **/
/******************************************************************************************************************************************/
register_nav_menus( array(
    'primary' => __( 'Primary Navigation', 'multi-color' )
) );

function callback_menu() {
    wp_page_menu('menu_class=automenu');
}

/******************************************************************************************************************************************/
/** Function to explicitly remove title attribute from links **/
/******************************************************************************************************************************************/
function remove_title_attribute($subject) {
    $result = preg_replace('/title=\"(.*?)\"/','',$subject);
    return $result;
}

/******************************************************************************************************************************************/
/** Function to resize an image **/
/******************************************************************************************************************************************/
function imageResize($width, $height, $target) { 

    if ($width > $height) { 
    $percentage = ($target / $width); 
    } else { 
    $percentage = ($target / $height); 
    } 
    
    $width = round($width * $percentage); 
    $height = round($height * $percentage); 
    
    return 'width="'.$width.'" height="'.$height.'"'; 

}

/******************************************************************************************************************************************/
/** Function to retrieve the first image in the post **/
/******************************************************************************************************************************************/
function get_post_image() {
  global $post, $posts;
  $first_img = '';
  ob_start();
  ob_end_clean();
  $output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);
  $first_img = $matches [1] [0];

  if(empty($first_img)){ //Defines a default image
    $first_img = "";
  } else {
    $imagesize = getimagesize($first_img);
    $resized = imageResize($imagesize[0],$imagesize[1],MAG_THUMB);
    $first_img = '<img class="magazine_thumb" '.$resized.' src="'.$first_img.'" />';
  }
  return $first_img;
}

/******************************************************************************************************************************************/
/** Function to strip leading brackets from the excerpts **/
/******************************************************************************************************************************************/
function srip_excerpt_more($more) {
	return '...';
}
add_filter('excerpt_more', 'srip_excerpt_more');

/******************************************************************************************************************************************/
/** Function to trim words from content **/
/******************************************************************************************************************************************/
/* Function takes string, number of characters to display and delimiter (optional) as input */
function trim_words($str, $n, $delim='...') {
   $len = strlen($str);
   if ($len > $n) {
       preg_match('/(.{' . $n . '}.*?)\b/', $str, $matches);
       return rtrim($matches[1]) . $delim;
   }
   else {
       return $str;
   }
}

/******************************************************************************************************************************************/
/** Comment callback function **/
/******************************************************************************************************************************************/
function multicolor_comment($comment,$args,$depth) {
    $GLOBALS['comment'] = $comment; ?>
    <li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
        <div id="comment-<?php comment_ID(); ?>">
            <div class="comment-header">
                <div class="vcard" style="float:left;width:48px;margin-right:20px;">
                    <?php if(function_exists('get_avatar')) { echo get_avatar($comment, '48'); } ?>
                </div>
                <div class="comment-meta" style="float:left;width:87%;">
                    <p class="comment-author"><?php comment_author_link() ?></p>
                    <p class="comment-date"><?php printf( __('%1$s'), get_comment_time(__('F jS, Y')) ); ?></p>
                    <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
                    <?php if ($comment->comment_approved == '0') : ?>
                        <p class="commentwait"><?php _e('Your comment is awaiting moderation.','multi-color') ?></p>
                    <?php endif; ?>
                </div>
                <div class="clear"></div>
            </div>
            <div class="comment-text">
                <?php comment_text() ?>
            </div>
        </div>
<?php            
}
?>